NemuTracking class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearUserId(
) → void -
getDeepLinkData(
) → Future< DeepLinkData?> -
getLastSessionHistory(
) → Future< TrackingSessionHistory?> -
init(
NemuInitParams params) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDeepLink(
DeepLinkCallback callback) → VoidCallback -
setUserId(
String userId) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → NemuTracking
-
final