Attribution class
Constructors
- Attribution({required String status, AttributionDetail? attribution, DeepLinkDetail? deepLink, SessionDetail? session})
-
const
-
Attribution.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attribution → AttributionDetail?
-
final
- deepLink → DeepLinkDetail?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → SessionDetail?
-
final
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited