DeepLinkData class
Constructors
- DeepLinkData({String? deepLinkValue, required bool isDeferred, UtmData? utms})
-
const
-
DeepLinkData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deepLinkValue → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeferred → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- utms → UtmData?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited